@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide access to hundreds of possible chord progressions
 
-our $VERSION = '0.0201';
+our $VERSION = '0.0300';
 
 use strict;
 use warnings;
@@ -11,6 +11,14 @@ use warnings;
 use Text::CSV_XS ();
 use File::ShareDir qw(dist_dir);
 use Music::Scales qw(get_scale_notes);
+use Exporter 'import';
+
+our @EXPORT = qw(
+    as_file
+    as_list
+    as_hash
+    transpose
+);
 
 
 
@@ -91,19 +99,17 @@ Data::Dataset::ChordProgressions - Provide access to hundreds of possible chord
 
 =head1 VERSION
 
-version 0.0201
+version 0.0300
 
 =head1 SYNOPSIS
 
-  use Data::Dataset::ChordProgressions;
+  use Data::Dataset::ChordProgressions qw(as_file as_list as_hash transpose);
 
-  my $filename = Data::Dataset::ChordProgressions::as_file();
+  my $filename = as_file();
+  my @data = as_list();
+  my %data = as_hash();
 
-  my @data = Data::Dataset::ChordProgressions::as_list();
-
-  my %data = Data::Dataset::ChordProgressions::as_hash();
-
-  my $named = Data::Dataset::ChordProgressions::transpose(
+  my $named = transpose(
     'A', 'major', ['C-F-Am-F', 'I-IV-vi-IV']
   );
 
@@ -132,19 +138,19 @@ the original list said nothing about who made it or how.
 
 =head2 as_file
 
-  $filename = Data::Dataset::ChordProgressions::as_file();
+  $filename = as_file();
 
 Return the data filename location.
 
 =head2 as_list
 
-  @data = Data::Dataset::ChordProgressions::as_list();
+  @data = as_list();
 
 Return the data as an array.
 
 =head2 as_hash
 
-  %data = Data::Dataset::ChordProgressions::as_hash();
+  %data = as_hash();
 
 Return the data as a hash.
 
